@@ -12,8 +12,24 @@ from .TemplateOptions import TemplateOptions
 from .TemplateRenderer import TemplateRenderer
 from .utils import download
 
-API_URL = "https://api.curvenote.com"
-TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/{template_name}/download"
+CURVENOTE_API_URL = os.getenv("CURVENOTE_API_URL")
+API_URL = (
+    CURVENOTE_API_URL if CURVENOTE_API_URL is not None else "https://api.curvenote.com"
+)
+TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/tex/{template_name}/download"
+OLD_TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/{template_name}/download"
+
+
+def do_download(URL: str, template_name: str):
+    url = URL.format(api_url=API_URL, template_name=template_name)
+    logging.info(f"DOWNLOAD: {url}")
+    try:
+        download_info = requests.get(url).json()
+        if "status" in download_info and download_info["status"] != 200:
+            raise ValueError(f'{template_name} not found - {download_info["status"]}')
+    except requests.exceptions.RequestException as e:
+        raise ValueError(f"Requests error - {url} - {e}")
+    return download_info
 
 
 class PublicTemplateLoader(TemplateLoader):
@@ -26,17 +42,18 @@ class PublicTemplateLoader(TemplateLoader):
         logging.info("Writing to target folder: %s", self._target_folder)
 
         logging.info("Looking up template %s", template_name)
+        logging.info("latest code")
         try:
-            logging.info(
-                TEMPLATE_DOWNLOAD_URL.format(
-                    api_url=API_URL, template_name=template_name
+            download_info = {}
+            try:
+                name = (
+                    template_name
+                    if template_name.startswith("public/")
+                    else f"public/{template_name}"
                 )
-            )
-            download_info = requests.get(
-                TEMPLATE_DOWNLOAD_URL.format(
-                    api_url=API_URL, template_name=template_name
-                )
-            ).json()
+                download_info = do_download(TEMPLATE_DOWNLOAD_URL, name)
+            except:
+                download_info = do_download(OLD_TEMPLATE_DOWNLOAD_URL, template_name)
             if "link" not in download_info:
                 typer.echo(f"Template '{template_name}' not found")
                 raise typer.Exit(-1)
@@ -48,7 +65,7 @@ class PublicTemplateLoader(TemplateLoader):
         logging.info(f"Found template, download url {download_info['link']}")
         logging.info("downloading...")
         zip_filename = os.path.join(
-            self._target_folder, f"{template_name}.template.zip"
+            self._target_folder, f"{template_name.replace('/','_')}.template.zip"
         )
         download(download_info["link"], zip_filename)
 
