@@ -1,15 +1,15 @@
 import logging
 import os
-from typing import Any, Dict, List, Optional, Set, Union, cast
+from typing import Any, Dict, List, Set, Union, cast
 
 import pkg_resources
-import yaml
 from pykwalify.core import Core
 
-from jtex.TexFormat import TexFormat
+from .TexFormat import TexFormat
 
 SCHEMA_PATH = pkg_resources.resource_filename("jtex", "schema")
 
+
 class Tag:
     def __init__(self, id: str, plain: bool):
         self.id = id
@@ -21,6 +21,7 @@ class Tag:
     def __hash__(self):
         return hash(self.id)
 
+
 class TemplateOptions:
     def __init__(self, template_location: str):
         self._template_location: str = template_location
@@ -40,17 +41,6 @@ class TemplateOptions:
         )
         self._parser.validate(raise_exception=True)
 
-        # now that schemas are loaded, we can configure additional options
-        self._tex_format: TexFormat = (
-            TexFormat.tex
-            if self.get("config.build.vanilla")
-            else TexFormat.tex_curvenote
-        )
-
-    @property
-    def tex_format(self) -> TexFormat:
-        return self._tex_format
-
     @property
     def template_location(self):
         return self._template_location
